@@ -12,10 +12,10 @@ import logging
 from org.codeforrussia.selector.standardizer.standardizer_registry_factory import SupportedInputFormat, StandardizerRegistryFactory
 from org.codeforrussia.selector.standardizer.schemas.schema_registry_factory import StandardProtocolSchemaRegistryFactory
 
-def add_gcp_connection(pipeline_options: PipelineOptions):
-    if pipeline_options.google_application_credentials is not None:
+def add_gcp_connection(known_args):
+    if known_args.google_application_credentials is not None:
         import os
-        os.environ["GOOGLE_APPLICATION_CREDENTIALS"] = pipeline_options.google_application_credentials
+        os.environ["GOOGLE_APPLICATION_CREDENTIALS"] = known_args.google_application_credentials
 
 
 def run(argv=None, save_main_session=True):
@@ -38,8 +38,16 @@ def run(argv=None, save_main_session=True):
                         required=True,
                         help='Output file to write results to')
 
+    parser.add_argument('--google-application-credentials',
+                        type=str,
+                        dest='google_application_credentials',
+                        required=False,
+                        help='GCP connection key file path')
+
     known_args, pipeline_args = parser.parse_known_args(argv)
 
+    add_gcp_connection(known_args)
+
     schema_registry = StandardProtocolSchemaRegistryFactory.get_schema_registry()
 
     registered_schema_keys = schema_registry.get_all_registered_schema_keys()
@@ -47,7 +55,7 @@ def run(argv=None, save_main_session=True):
     standardizer = StandardizerRegistryFactory.get_standardizer_registry(schema_registry_factory=StandardProtocolSchemaRegistryFactory).get_standardizer(known_args.input_data_format)
 
     pipeline_options = PipelineOptions(pipeline_args)
-    add_gcp_connection(pipeline_options)
+
     pipeline_options.view_as(SetupOptions).save_main_session = save_main_session
 
     with beam.Pipeline(options=pipeline_options) as p:
